==> fwmx-1.2-20220511.tgz: fwmx-1.2-20220511/fwm/taskbar.h <==
/*
 * This file is part of firk's window manager for x11 (fwm)
 * Copyright (C) 2016-2021 firk <firk@cantconnect.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef _FWM_TASKBAR_H
#define _FWM_TASKBAR_H

extern int taskbar_created;
extern Window taskbar_window;
extern Window bg_window;


extern void taskbar_update(void);
extern void taskbar_destroy(void);
extern void taskbar_handle_event(XEvent * ev);
extern int  taskbar_add_winfo(Window window);
extern int  taskbar_upd_winfo(Window window);
extern int  taskbar_del_winfo(Window window);
extern WInfo * taskbar_search_winfo(Window window);
extern void taskbar_fix_focus(void);
extern int  taskbar_focus_window(Window window);
extern int  taskbar_minimize_window(Window window);
extern int  taskbar_toggle_maximize(Window window);
extern WInfo * taskbar_get_focuswin(void);
extern void taskbar_toggle_fullscreen_focus(void);
extern void taskbar_toggle_ontop_focus(void);
extern void taskbar_next_window(void);
extern void taskbar_prev_window(void);
extern void taskbar_zprev_window(void);
extern void taskbar_zprev_window_finish(void);

extern void taskbar_timer_update(int force_all);
extern void taskbar_periodic(void);

#endif

==> fwmx-1.3-20230919.tgz: fwmx-1.3-20230919/fwm/taskbar.h <==
/*
 * This file is part of firk's window manager for x11 (fwm)
 * Copyright (C) 2016-2023 firk <firk@cantconnect.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef _FWM_TASKBAR_H
#define _FWM_TASKBAR_H

extern int taskbar_created;
extern Window taskbar_window;
extern Window bg_window;
extern GC taskbar_gc;
extern int taskbar_x0;
extern int taskbar_y0;
extern int taskbar_width;
extern int taskbar_height;

extern void taskbar_update(void);
extern void taskbar_destroy(void);
extern void taskbar_handle_event(XEvent * ev);
extern WInfo * taskbar_add_winfo(Window window);
extern int  taskbar_upd_winfo(WInfo * wi);
extern void taskbar_del_winfo(WInfo * wi);
extern void taskbar_fix_focus(void);
extern int  taskbar_focus_window(WInfo * wi);
extern int  taskbar_minimize_window(WInfo * wi);
extern int  taskbar_toggle_maximize(WInfo * wi);
extern WInfo * taskbar_get_focuswin(void);
extern void taskbar_toggle_fullscreen_focus(void);
extern void taskbar_toggle_ontop_focus(void);
extern void taskbar_next_window(void);
extern void taskbar_prev_window(void);
extern void taskbar_zprev_window(void);
extern void taskbar_zprev_window_finish(void);

#endif
